@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/installer/RCS/manifest.tcl,v $
-# $Date: 1999/06/25 10:58:19 $
-# $Revision: 1.18.1.275 $
+# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/manifest.tcl,v $
+# $Date: 1999/07/23 09:48:03 $
+# $Revision: 1.18.1.283 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -70,6 +70,7 @@ array set Manifest [list  \
     [file join installer file76.tcl]		{} \
     [file join installer file80.tcl]		{} \
     [file join installer file81.tcl]		{} \
+    [file join installer file82.tcl]		{} \
     [file join installer support.tcl]		{} \
     [file join installer mac.tcl]		{} \
     [file join installer macfile.tcl]		{} \
@@ -155,6 +156,7 @@ array set Manifest [list  \
     [file join lib tcl76.tcl]			{copy} \
     [file join lib tcl80.tcl]			{copy} \
     [file join lib tcl81.tcl]			{copy} \
+    [file join lib tcl82.tcl]			{copy} \
     [file join lib Unix.tcl]			{copy} \
     [file join lib Windows.tcl]			{copy} \
     [file join lib debug.tcl]			{copy} \
@@ -177,72 +179,137 @@ array set Manifest [list  \
     [file join samples zircon.ad]		{ncopy} \
     [file join samples Preferences]		{} \
     [file join samples Netspaces 3Dnet]		{} \
+    [file join samples Netspaces AMnet]		{} \
     [file join samples Netspaces Afternet]	{} \
+    [file join samples Netspaces Airnet]	{} \
+    [file join samples Netspaces Alternativenet]       {} \
     [file join samples Netspaces AngelEyes]	{} \
+    [file join samples Netspaces Asianet]	{} \
+    [file join samples Netspaces Asixnet]       {} \
+    [file join samples Netspaces Astrolink]	{} \
     [file join samples Netspaces Asylumnet]	{} \
-    [file join samples Netspaces Auslink]	{} \
-    [file join samples Netspaces Austnet]	{} \
+    [file join samples Netspaces Austnet]       {} \
+    [file join samples Netspaces Badnet]	{} \
     [file join samples Netspaces BeyondIRC]	{} \
-    [file join samples Netspaces Bicnet]	{} \
-    [file join samples Netspaces BrasIRC]	{} \
-    [file join samples Netspaces Brasilnet]	{} \
-    [file join samples Netspaces Brasnet]	{} \
+    [file join samples Netspaces Blazednet]	{} \
+    [file join samples Netspaces Brasirc]       {} \
+    [file join samples Netspaces Brasirc-com]	{} \
+    [file join samples Netspaces Brasnet]       {} \
+    [file join samples Netspaces CCnet]		{} \
+    [file join samples Netspaces CMDnet]	{} \
+    [file join samples Netspaces CNN]		{} \
     [file join samples Netspaces Castlenet]	{} \
-    [file join samples Netspaces Chatnet]	{} \
-    [file join samples Netspaces Cobranet]	{} \
+    [file join samples Netspaces Chatcircuit]	{} \
+    [file join samples Netspaces Chatlink]	{} \
+    [file join samples Netspaces Chatnet]       {} \
+    [file join samples Netspaces Circanet]	{} \
     [file join samples Netspaces Cynet]		{} \
     [file join samples Netspaces DALnet]	{} \
+    [file join samples Netspaces DC-net]	{} \
+    [file join samples Netspaces Darkernet]	{} \
+    [file join samples Netspaces Darkfire]	{} \
+    [file join samples Netspaces Darknet]       {} \
+    [file join samples Netspaces Darktree]	{} \
     [file join samples Netspaces Darkzone]	{} \
-    [file join samples Netspaces DragonNet]	{} \
+    [file join samples Netspaces Deepspace]	{} \
+    [file join samples Netspaces Different]	{} \
+    [file join samples Netspaces Dobbernet]	{} \
+    [file join samples Netspaces DreamMyst]	{} \
+    [file join samples Netspaces Dreamnet]	{} \
+    [file join samples Netspaces DuDinet]	{} \
+    [file join samples Netspaces Duh-net]       {} \
+    [file join samples Netspaces Dynastynet]	{} \
+    [file join samples Netspaces EDUchat]       {} \
     [file join samples Netspaces EFnet]		{} \
     [file join samples Netspaces EICN]		{} \
-    [file join samples Netspaces Edunet]	{} \
     [file join samples Netspaces Escapenet]	{} \
     [file join samples Netspaces Esprit]	{} \
+    [file join samples Netspaces Etherlands]	{} \
     [file join samples Netspaces FDFnet]	{} \
     [file join samples Netspaces FEFnet]	{} \
     [file join samples Netspaces Firestar]	{} \
+    [file join samples Netspaces Forestnet]	{} \
+    [file join samples Netspaces FoxChat]       {} \
     [file join samples Netspaces Galaxynet]	{} \
     [file join samples Netspaces Gamesnet]	{} \
     [file join samples Netspaces Gammaforce]	{} \
     [file join samples Netspaces Gammanet]	{} \
-    [file join samples Netspaces Hispano]	{} \
+    [file join samples Netspaces GlobalIRC]	{} \
+    [file join samples Netspaces Grnet]		{} \
+    [file join samples Netspaces IRC-Chat]	{} \
+    [file join samples Netspaces IRC-Hispanonet]	{} \
+    [file join samples Netspaces IRC-Hispanoorg]	{} \
     [file join samples Netspaces IRCLink]	{} \
     [file join samples Netspaces IRCnet]	{} \
-    [file join samples Netspaces KPNet]		{} \
+    [file join samples Netspaces Kewl.org]	{} \
     [file join samples Netspaces Kidsworld]	{} \
     [file join samples Netspaces Knightnet]	{} \
+    [file join samples Netspaces Krushnet]	{} \
     [file join samples Netspaces Lagnet]	{} \
-    [file join samples Netspaces Magicstar]	{} \
-    [file join samples Netspaces MircX]		{} \
+    [file join samples Netspaces Littlenet]	{} \
+    [file join samples Netspaces Lunatics]	{} \
+    [file join samples Netspaces MagicStar]	{} \
+    [file join samples Netspaces MegaIRC]       {} \
+    [file join samples Netspaces Mellorien]	{} \
+    [file join samples Netspaces Millenia]	{} \
+    [file join samples Netspaces Moonet]	{} \
+    [file join samples Netspaces Mystical]	{} \
+    [file join samples Netspaces NDRSnet]       {} \
+    [file join samples Netspaces Netlink]       {} \
+    [file join samples Netspaces Netlink-irc]	{} \
     [file join samples Netspaces Newnet]	{} \
     [file join samples Netspaces Nightstar]	{} \
+    [file join samples Netspaces Nocnet]	{} \
+    [file join samples Netspaces Novernet]	{} \
+    [file join samples Netspaces Optimus.Org]	{} \
     [file join samples Netspaces Othernet]	{} \
+    [file join samples Netspaces Otherside]	{} \
     [file join samples Netspaces OzOrg]		{} \
     [file join samples Netspaces PTnet]		{} \
-    [file join samples Netspaces PerthNet]	{} \
-    [file join samples Netspaces Phantasy]	{} \
-    [file join samples Netspaces PrizonNet]	{} \
+    [file join samples Netspaces Phantomnet]	{} \
+    [file join samples Netspaces Phishynet]	{} \
+    [file join samples Netspaces Phrozen]       {} \
+    [file join samples Netspaces Pseudonet]	{} \
+    [file join samples Netspaces Qualitynet]	{} \
+    [file join samples Netspaces RODnet]	{} \
+    [file join samples Netspaces Red-Latina]	{} \
     [file join samples Netspaces RedLatina]	{} \
-    [file join samples Netspaces Sandnet]	{} \
-    [file join samples Netspaces SomeNet]	{} \
+    [file join samples Netspaces RedeBrasil]	{} \
+    [file join samples Netspaces RedeSul]	{} \
+    [file join samples Netspaces Relicnet]	{} \
+    [file join samples Netspaces Sandnet]       {} \
+    [file join samples Netspaces Sandnet-org]	{} \
+    [file join samples Netspaces SaturnChat]	{} \
+    [file join samples Netspaces ShadowFire]	{} \
+    [file join samples Netspaces Singaporenet]	{} \
     [file join samples Netspaces Sorcerynet]	{} \
+    [file join samples Netspaces Spidernet]	{} \
     [file join samples Netspaces StarChat]	{} \
+    [file join samples Netspaces StarFusion]	{} \
     [file join samples Netspaces StarLink]	{} \
     [file join samples Netspaces StarLinkIRC]	{} \
     [file join samples Netspaces Superchat]	{} \
     [file join samples Netspaces Sysopnet]	{} \
-    [file join samples Netspaces Ultranet]	{} \
+    [file join samples Netspaces Teenzone]	{} \
+    [file join samples Netspaces TerraX]	{} \
+    [file join samples Netspaces Tr-net]	{} \
+    [file join samples Netspaces TrIrcnet]	{} \
+    [file join samples Netspaces UnderZ]	{} \
     [file join samples Netspaces Undernet]	{} \
+    [file join samples Netspaces Undienet]	{} \
+    [file join samples Netspaces UnionLatina]	{} \
+    [file join samples Netspaces UnixFreak]	{} \
     [file join samples Netspaces Valhall]	{} \
+    [file join samples Netspaces Vitamina]	{} \
     [file join samples Netspaces WIFLnet]	{} \
+    [file join samples Netspaces Warpednet]	{} \
     [file join samples Netspaces Webnet]	{} \
-    [file join samples Netspaces Windsornet]	{} \
+    [file join samples Netspaces WonKnet]	{} \
     [file join samples Netspaces WorldIRC]	{} \
-    [file join samples Netspaces Wwfin]		{} \
     [file join samples Netspaces XWorld]	{} \
     [file join samples Netspaces Xnet]		{} \
     [file join samples Netspaces ZAnet]		{} \
+    [file join samples Netspaces ZUHnet]	{} \
     scripts					{dmake} \
     sounds					{dmake} \
     [file join util findMeta]			{} \
@@ -251,5 +318,5 @@ array set Manifest [list  \
 set Index "lib [file join plugins Dcc] [file join plugins Sed]"
 #
 set Version 1.18
-set Patchlevel 217
+set Patchlevel 221
 
