@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1999/05/17 09:18:22 $
-# $Revision: 1.18.1.187 $
+# $Date: 1999/07/07 12:13:06 $
+# $Revision: 1.18.1.188 $
 #
 #
 package provide zircon 1.18
@@ -1658,7 +1658,7 @@ proc channel_mode {this vals prefix} {
 			    handleOn $net MODE [list [$this name] -$m {} $prefix]
 			}
 		    }
-		b - k - o - v { append nxt $flag$m }
+		b - e - k - o - v { append nxt $flag$m }
 		a {
 			set w $cdata(window)
 			if {[set cdata(a) [string match + $flag]]} {
@@ -1729,6 +1729,10 @@ proc channel_mode {this vals prefix} {
 	    b   {
 		    banProtect $this $prefix $flag $par
 		}
+	    e   {
+	    	    # No idea what to do with this one
+		    # if anything needs to be done that is.
+	        }
 	    }
 	    set nxt [string range $nxt 2 end]
 	    handleOn $net MODE [list [$this name] $flag$m $par $prefix]
