@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Info.tcl,v $
-# $Date: 1998/07/14 15:42:23 $
-# $Revision: 1.18.1.38 $
+# $Date: 1999/02/01 09:32:04 $
+# $Revision: 1.18.1.40 $
 #
 package provide zircon 1.18
 #
@@ -35,18 +35,18 @@ proc Info {args} {
       -ircIImode [$net ircIImode]
     grid rowconfigure $w 0 -weight 1
     grid columnconfigure $w 0 -weight 1
-    frame $w.cl -borderwidth 0
-    grid columnconfigure $w.cl 0 -weight 1
-    scrollbar $w.cl.hs -orient horizontal -command "$w.cl.cmd xview"
-    emacsEntry $w.cl.cmd -xscrollcommand "ghsSet $w.cl.hs" \
+    frame $w.cmd -borderwidth 0
+    grid columnconfigure $w.cmd 0 -weight 1
+    scrollbar $w.cmd.hs -orient horizontal -command "$w.cmd.entry xview"
+    emacsEntry $w.cmd.entry -xscrollcommand "ghsSet $w.cmd.hs" \
       -relief sunken -state disabled
-    button $w.cl.clear -text [trans clear] -command "$name clear" -width 5 \
+    button $w.cmd.clear -text [trans clear] -command "$name clear" -width 5 \
       -borderwidth 2 -highlightthickness 2 -pady 0
-    grid $w.cl.cmd $w.cl.clear -sticky ew
-    grid $w.cl.hs - -sticky ew
-    if {[$net command]} { grid $w.cl -row 1 -columnspan 2 -sticky ew }
-    doInfoBindings $w.cl.cmd $name
-    bind $w.cl.cmd <Return> "$name doCmd %W"
+    grid $w.cmd.entry $w.cmd.clear -sticky ew
+    grid $w.cmd.hs - -sticky ew
+    if {[$net command]} { grid $w.cmd -row 1 -columnspan 2 -sticky ew }
+    doInfoBindings $w.cmd.entry $name
+    bind $w.cmd.entry <Return> "$name doCmd %W"
     set idata(text) [set oft $w.info]
     scrollbar $w.vscroller -command "$oft yview"
     text $oft -height 10 -width 80 \
@@ -70,7 +70,7 @@ proc info_delete {this} { mcnDelete $this ITO[$this net] info }
 #
 proc info_onShow {this} { }
 #
-proc info_clear {this} {
+proc info_clear {this args} {
    [$this text] delete 1.0 end
    update idletasks
 }
@@ -84,15 +84,6 @@ proc info_send {this string args} {
     } { bell }
 }
 #
-proc info_command {this on} {
-    upvar #0 $this idata
-    if {$on} {
-	grid $idata(window).cl
-    } {
-	grid forget $idata(window).cl
-    }
-}
-#
 proc info_doCmd {this w} { [$this net] doMisc2 $this $w }
 #
 proc info_call {this op pars} {
@@ -103,9 +94,9 @@ proc info_call {this op pars} {
     control { return [$idata(net) control] }
     command {
 	    if {[lindex $pars 0]} {
-		grid $idata(window).cl
+		grid $idata(window).cmd
 	    } {
-		grid forget $idata(window).cl
+		grid forget $idata(window).cmd
 	    }
 	    return
 	}
@@ -124,7 +115,7 @@ proc info_popup {this} {
 #
 proc info_insert {this text} {
     switch {} $text return
-    set ent [$this window].cl.cmd
+    set ent [$this window].cmd.entry
     while {[regexp "(\[^\n\]*)\n(.*)" $text d line text]} {
 	switch {} $line continue
 	tkEntryInsert $ent $line
@@ -138,7 +129,7 @@ proc info_insert {this text} {
 }
 #
 proc info_flagState {this state} {
-    [$this window].cl.cmd configure -state $state
+    [$this window].cmd.entry configure -state $state
 }
 #
 proc info_close {this} {
