@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/catless/Zircon/lib/RCS/Windows.tcl,v $
-# $Date: 1998/02/09 16:56:59 $
-# $Revision: 1.18.1.5 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Windows.tcl,v $
+# $Date: 1998/11/03 09:40:32 $
+# $Revision: 1.18.1.6 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -18,7 +18,7 @@ proc tmpdir {} {
     return $env(TEMP)
 }
 #
-proc prefdir {} { return [file join [glob ~] .zircon] }
+proc prefdir {} { return [file join [lindex [glob ~] 0] .zircon] }
 #
 proc username {} { return {ZirconUser} }
 #
