@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/errors.tcl,v $
-# $Date: 1998/04/14 12:22:01 $
-# $Revision: 1.18.1.18 $
+# $Source: /catless/catless/nlfm/Working/Zircon/Released/lib/RCS/errors.tcl,v $
+# $Date: 1998/04/27 11:46:10 $
+# $Revision: 1.18.1.21 $
 #
 package provide zircon 1.18
 #
@@ -33,7 +33,8 @@ proc irc406 {net prefix param pargs} {
 }
 #
 proc resetNick {net} {
-    [$net control] configure -nickname [$net nickname]
+    [$net control] confirmNick [$net nickname]
+    $net configure -nickwait 0
 }
 #
 proc irc422 {net prefix param pargs} {
@@ -57,6 +58,11 @@ proc irc437 {net prefix param pargs} {
     }
 }
 #
+proc irc438 {net prefix param pargs} {
+    resetNick $net
+    tellError $net {Nickname Error} "[lindex $pargs 1] : $param"
+}
+#
 proc tryNick {net nk} {
     $net NICK $nk
     $net configure -nickname $nk
@@ -85,7 +91,11 @@ proc cantUseNick {net prefix param pargs msg} {
 #
 proc irc442 {net prefix param pargs} {
     if {[[set ch [Channel :: find [set nm [lindex $pargs 1]] $net]] active]} {
-	$ch addText @ERROR "*** Error 442 : $nm $param [lindex $pargs 2]"
+        if {[$ch leaving]} {
+	    $ch delete
+	} {
+	    $ch addText @ERROR "*** Error 442 : $nm $param [lindex $pargs 2]"
+	}
     } {
 	tellError $net {Channel Error} "$nm $param [lindex $pargs 2]"
     }
