@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/misc2.tcl,v $
-# $Date: 1998/07/16 11:11:23 $
-# $Revision: 1.18.1.41 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
+# $Date: 1999/01/29 13:08:55 $
+# $Revision: 1.18.1.42 $
 #
 #
 package provide zircon 1.18
@@ -40,6 +40,12 @@ proc ircII_/ADMIN {net chid arg} { $net nsend ADMIN [lindex $arg 0]}
 #
 proc ircII_/ALIAS {net chid arg} { sillyPerson $net }
 #
+proc ircII_/AMSG {net chid arg} {
+    foreach x [$net channels] {
+        if {[$x active]} { $x send $arg }
+    }
+}
+#
 proc ircII_/ASSIGN {net chid arg} {
     upvar #0 uVars$net uvars
     set uvars([lindex $arg 0]) [lindex $arg 1]
